@@ -202,7 +202,7 @@ class Generator:
             )
             self.dec_logits = tf.identity(decoder_logits, name="dec_logits")
 
-            _, infer_path, _ = ptn_rnn_decoder(
+            _, beam_path, _ = ptn_rnn_decoder(
                 dec_cell, None,
                 self.enc, enc_init_state,
                 hp.seq_length, hp.res_length, hp.hidden_units * 2,
@@ -214,8 +214,23 @@ class Generator:
                 temperature=temperature,
                 train_sample=train_sample, predict_sample=predict_sample
             )
-            self.infer_path = tf.identity(infer_path, name="infer_path")
-            self.infer_result = batch_gather(self.item_cand, self.infer_path)
+            self.beam_path = tf.identity(beam_path, name="beam_path")
+            self.beam_result = batch_gather(self.item_cand, self.beam_path)
+
+            _, greedy_path, _ = ptn_rnn_decoder(
+                dec_cell, None,
+                self.enc, enc_init_state,
+                hp.seq_length, hp.res_length, hp.hidden_units * 2,
+                hp.num_glimpse, self.batch_size,
+                self.l1_mask, self.l2_mask, self.l3_mask,
+                self.t0_mask, self.t1_mask, self.t2_mask, self.t3_mask, self.t4_mask,
+                l0_ssr_mask, taohua_mask,
+                mode="GREEDY", reuse=True, beam_size=None,
+                temperature=temperature,
+                train_sample=train_sample, predict_sample=predict_sample
+            )
+            self.greedy_path = tf.identity(greedy_path, name="greedy_path")
+            self.greedy_result = batch_gather(self.item_cand, self.greedy_path)
 
         if is_training:
             # Loss
