@@ -47,6 +47,15 @@ def compile_model(model, config):
 
     sess = K.get_session()
     sess.run(tf.compat.v1.local_variables_initializer())
-    sess.run(tf.compat.v1.global_variables_initializer())
+    # sess.run(tf.compat.v1.global_variables_initializer())
+    uninit_vars = []
+    # 用 try & except 语句块捕获：
+    for var in tf.all_variables():
+        try:
+            sess.run(var)
+        except tf.errors.FailedPreconditionError:
+            uninit_vars.append(var)
+    init_new_vars_op = tf.initialize_variables(uninit_vars)
+    sess.run(init_new_vars_op)
     sess.run(tf.compat.v1.tables_initializer())
     return model, sess
