@@ -75,13 +75,14 @@ class FeatureUtil(object):
         cur_time = [int(sample.split('@')[feature_id['cur_time']]) for sample in data]
 
         sequence_id = [
-            [[int(x.split(':')[0]) for x in
+            [[float(x.split(':')[0]) for x in
               sorted(re.split(', |,', xx), key=lambda x: x.split(':')[-1])][-self.maxlen:] if xx else [0] for xx in
              sample.split('@')[feature_id['sequence_feature']].split(';')[:self.seq_num]]
             for sample in data]
+
         sequence_time = [
             [[int(sample.split('@')[feature_id['cur_time']]) - int(x.split(':')[1]) for x in
-              sorted(re.split(', |,', xx), key=lambda x: x.split(':')[-1])][-self.maxlen:] if xx else [0] for xx in
+              sorted(re.split(', |,', xx), key=lambda x: x.split(':')[-1])][-self.maxlen:] if ':' in xx else [0]*len(re.split(', |,', xx)) for xx in
              sample.split('@')[feature_id['sequence_feature']].split(';')[:self.seq_num]]
             for sample in data]
         sequence_time_gaps = [[[0] + [abs(xx[i] - xx[i - 1]) for i in range(1, len(xx))] for xx in sample] for sample in sequence_time]
@@ -107,7 +108,7 @@ class FeatureUtil(object):
             # mask、label，处理成 multi-hot
             mask, label = self.mask_label_multi_hot(mask, label)
 
-            return np.array(role_id_hash), np.array(sequence_id), np.array(sequence_time), np.array(sequence_time_gaps), \
+            return np.array(role_id), np.array(sequence_id), np.array(sequence_time), np.array(sequence_time_gaps), \
                    np.array(cross_features_index), np.array(cross_features_val), np.array(user_features_id), np.array(cur_time), \
                    np.array(mask), np.array(label)
 
@@ -123,7 +124,7 @@ class FeatureUtil(object):
             # mask、label，处理成 multi-hot
             mask, label = self.mask_label_multi_hot(mask, label)
 
-            return np.array(role_id_hash, dtype=np.int64), np.array(sequence_id, dtype=np.int64), \
+            return np.array(role_id, dtype=np.int64), np.array(sequence_id, dtype=np.float32), \
                    np.array(sequence_time, dtype=np.int64), np.array(sequence_time_gaps, dtype=np.int64), \
                    cross_features_index, cross_features_val, \
                    np.array(user_features_id, dtype=np.int64), np.array(cur_time, dtype=np.int64), \
@@ -131,7 +132,7 @@ class FeatureUtil(object):
 
         elif write_to == 'tfrecord':
             # 生成的特征用于写入tfrecord
-            return role_id_hash, sequence_id, sequence_time, sequence_time_gaps, \
+            return role_id, sequence_id, sequence_time, sequence_time_gaps, \
                    cross_features_index, cross_features_val, user_features_id, \
                    cur_time, mask, label
 
@@ -220,7 +221,7 @@ class FeatureUtil(object):
                 mask = masks[i]
                 cur_time = cur_times[i]
 
-                sequence_id_feature = [tf.train.Feature(int64_list=tf.train.Int64List(value=sequence_id[i])) for i in range(self.seq_num)]
+                sequence_id_feature = [tf.train.Feature(float_list=tf.train.FloatList(value=sequence_id[i])) for i in range(self.seq_num)]
                 sequence_time_feature = [tf.train.Feature(int64_list=tf.train.Int64List(value=sequence_time[i])) for i in range(self.seq_num)]
                 sequence_time_gaps_feature = [tf.train.Feature(int64_list=tf.train.Int64List(value=sequence_time_gaps[i])) for i in range(self.seq_num)]
 
