@@ -18,7 +18,9 @@ class L20RecEnv(gym.Env):
 
     def __init__(self,
                  statefile, actionfile, newitemfile, modelfile, config,
-                 batch_size=None, one_step=False, reward_sqr=False, use_rslib_model=False, config_for_rslib_model=None, use_rule=True, reward_type='ctr', fenliu='1'):
+                 batch_size=None, one_step=False, reward_sqr=False, use_rslib_model=False,
+                 config_for_rslib_model=None, use_rule=True,test=False,obs_size=256,
+                 reward_type='ctr', fenliu='1'):
         self.graph = tf.Graph()  # 为每个类(实例)单独创建一个graph
         with self.graph.as_default():
 
@@ -31,7 +33,6 @@ class L20RecEnv(gym.Env):
 
         with self.sess.as_default():
             with self.graph.as_default():
-                obs_size = 256
                 if batch_size:
                     self.batch_size = batch_size
                     self.batch = True
@@ -42,11 +43,14 @@ class L20RecEnv(gym.Env):
                 self.reward_sqr = reward_sqr
                 self.use_rslib_model = use_rslib_model
                 self.use_rule = use_rule
+                self.test = test
 
                 self.saver.restore(self.sess, modelfile)  # 从恢复点恢复参数
                 self.src = L20RecEnvSrc(config, statefile, actionfile, newitemfile=newitemfile, batch_size=self.batch_size, reward_type=reward_type)
-                self.sim = L20RecSim(self.src, model, modelfile, self.sess, steps=9, batch_size=self.batch_size, reward_sqr=self.reward_sqr, use_rule=self.use_rule,fenliu =fenliu)
-                self.controllerobs = controllerObs(config, model, modelfile, self.sess, self.src, batch_size=self.batch_size, one_step=self.one_step, use_rule=self.use_rule)
+                self.sim = L20RecSim(self.src, model, modelfile, self.sess, steps=9, batch_size=self.batch_size,
+                                     reward_sqr=self.reward_sqr, use_rule=self.use_rule,fenliu =fenliu)
+                self.controllerobs = controllerObs(config, model, modelfile, self.sess, self.src, batch_size=self.batch_size,
+                                                   one_step=self.one_step, use_rule=self.use_rule,test=self.test)
                 self.action_space = gym.spaces.Discrete(config['class_num'])
                 self.observation_space = gym.spaces.Box(-10000.0, 10000.0, shape=(obs_size,))
                 if use_rslib_model:
