@@ -4,8 +4,8 @@ class L20RecEnvSrc(RecEnvSrc):
     '''
 
     '''
-    def __init__(self, config, statefile, actionfile, batch_size=None, reward_type='ctr_price'):
-        RecEnvSrc.__init__(self, config, statefile, actionfile, batch_size=batch_size, reward_type=reward_type)
+    def __init__(self, config, statefile, actionfile, newitemfile, batch_size=None, reward_type='ctr_price'):
+        RecEnvSrc.__init__(self, config, statefile, actionfile, newitemfile=newitemfile, batch_size=batch_size, reward_type=reward_type)
 
 
     def get_user_rawstate(self, role_ids):
